@@ -1,13 +1,12 @@
-use 5.008;    # utf8
+use 5.006;    # our
 use strict;
 use warnings;
-use utf8;
 
 package Dist::Zilla::PluginBundle::Author::KENTNL::Lite;
 
-our $VERSION = '2.001000';
+our $VERSION = '2.001001';
 
-# ABSTRACT: A Minimal Build-Only replacement for @Author::KENTNL for contributors.
+# ABSTRACT: (DEPRECATED) A Minimal Build-Only replacement for @Author::KENTNL for contributors.
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
@@ -231,11 +230,11 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::Author::KENTNL::Lite - A Minimal Build-Only replacement for @Author::KENTNL for contributors.
+Dist::Zilla::PluginBundle::Author::KENTNL::Lite - (DEPRECATED) A Minimal Build-Only replacement for @Author::KENTNL for contributors.
 
 =head1 VERSION
 
-version 2.001000
+version 2.001001
 
 =head1 SYNOPSIS
 
@@ -246,6 +245,13 @@ version 2.001000
     dzil test
     dzil release # BANG.
 
+=head1 DEPRECATED
+
+I'm no longer really keeping this up-to-date with my main bundle, and I've migrated to some other strategy.
+
+Any of my distributions that ship a <dist.ini.meta> are now flattened out into C<dist.ini> so that no bundles are
+implicated, and you can simply delete plugins that are inconveniencing you.
+
 =head1 NAMING SCHEME
 
 Please read my rant in L<Dist::Zilla::PluginBundle::Author::KENTNL/NAMING SCHEME> about the Author:: convention.
@@ -301,7 +307,7 @@ Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric <kentnl@cpan.org>.
+This software is copyright (c) 2017 by Kent Fredric <kentnl@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
